/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type sin_vec[] = {
{62, 0,123,__LINE__, 0xbfedd343, 0xa21a55c4, 0xbff33333, 0x33333333},	/* -0.932039=f(-1.2)*/
{63, 0,123,__LINE__, 0xbfedb532, 0xd61e9b5e, 0xbff30a3d, 0x70a3d70a},	/* -0.928369=f(-1.19)*/
{63, 0,123,__LINE__, 0xbfed965f, 0x591f4701, 0xbff2e147, 0xae147ae1},	/* -0.924606=f(-1.18)*/
{64, 0,123,__LINE__, 0xbfed76c9, 0xf52192ac, 0xbff2b851, 0xeb851eb8},	/* -0.920751=f(-1.17)*/
{63, 0,123,__LINE__, 0xbfed5673, 0x792177c3, 0xbff28f5c, 0x28f5c28f},	/* -0.916803=f(-1.16)*/
{62, 0,123,__LINE__, 0xbfed355c, 0xb90c6298, 0xbff26666, 0x66666666},	/* -0.912764=f(-1.15)*/
{63, 0,123,__LINE__, 0xbfed1386, 0x8dbbc585, 0xbff23d70, 0xa3d70a3d},	/* -0.908633=f(-1.14)*/
{64, 0,123,__LINE__, 0xbfecf0f1, 0xd4ef8bcd, 0xbff2147a, 0xe147ae14},	/* -0.904412=f(-1.13)*/
{63, 0,123,__LINE__, 0xbfeccd9f, 0x71486c5d, 0xbff1eb85, 0x1eb851eb},	/* -0.9001=f(-1.12)*/
{62, 0,123,__LINE__, 0xbfeca990, 0x4a421c93, 0xbff1c28f, 0x5c28f5c2},	/* -0.895699=f(-1.11)*/
{63, 0,123,__LINE__, 0xbfec84c5, 0x4c2d6337, 0xbff19999, 0x99999999},	/* -0.891207=f(-1.1)*/
{64, 0,123,__LINE__, 0xbfec5f3f, 0x682a0bc6, 0xbff170a3, 0xd70a3d70},	/* -0.886627=f(-1.09)*/
{63, 0,123,__LINE__, 0xbfec38ff, 0x9420ba3a, 0xbff147ae, 0x147ae147},	/* -0.881958=f(-1.08)*/
{62, 0,123,__LINE__, 0xbfec1206, 0xcabc9f76, 0xbff11eb8, 0x51eb851e},	/* -0.877201=f(-1.07)*/
{63, 0,123,__LINE__, 0xbfebea56, 0x0b650e82, 0xbff0f5c2, 0x8f5c28f5},	/* -0.872355=f(-1.06)*/
{64, 0,123,__LINE__, 0xbfebc1ee, 0x5a36f2c0, 0xbff0cccc, 0xcccccccc},	/* -0.867423=f(-1.05)*/
{63, 0,123,__LINE__, 0xbfeb98d0, 0xbffe273e, 0xbff0a3d7, 0x0a3d70a3},	/* -0.862404=f(-1.04)*/
{62, 0,123,__LINE__, 0xbfeb6efe, 0x4a2eaf61, 0xbff07ae1, 0x47ae147a},	/* -0.857299=f(-1.03)*/
{62, 0,123,__LINE__, 0xbfeb4478, 0x0addd102, 0xbff051eb, 0x851eb851},	/* -0.852108=f(-1.02)*/
{64, 0,123,__LINE__, 0xbfeb193f, 0x18bb1035, 0xbff028f5, 0xc28f5c28},	/* -0.846832=f(-1.01)*/
{63, 0,123,__LINE__, 0xbfeaed54, 0x8f090ced, 0xbfefffff, 0xfffffffe},	/* -0.841471=f(-1)*/
{62, 0,123,__LINE__, 0xbfeac0b9, 0x8d96429c, 0xbfefae14, 0x7ae147ac},	/* -0.836026=f(-0.99)*/
{62, 0,123,__LINE__, 0xbfea936f, 0x38b5aa0d, 0xbfef5c28, 0xf5c28f5a},	/* -0.830497=f(-0.98)*/
{64, 0,123,__LINE__, 0xbfea6576, 0xb9373da2, 0xbfef0a3d, 0x70a3d708},	/* -0.824886=f(-0.97)*/
{63, 0,123,__LINE__, 0xbfea36d1, 0x3c606027, 0xbfeeb851, 0xeb851eb6},	/* -0.819192=f(-0.96)*/
{62, 0,123,__LINE__, 0xbfea077f, 0xf3e4266e, 0xbfee6666, 0x66666664},	/* -0.813416=f(-0.95)*/
{63, 0,123,__LINE__, 0xbfe9d784, 0x15db83e3, 0xbfee147a, 0xe147ae12},	/* -0.807558=f(-0.94)*/
{64, 0,123,__LINE__, 0xbfe9a6de, 0xdcbd5a52, 0xbfedc28f, 0x5c28f5c0},	/* -0.80162=f(-0.93)*/
{62, 0,123,__LINE__, 0xbfe97591, 0x87566d08, 0xbfed70a3, 0xd70a3d6e},	/* -0.795602=f(-0.92)*/
{62, 0,123,__LINE__, 0xbfe9439d, 0x58c13792, 0xbfed1eb8, 0x51eb851c},	/* -0.789504=f(-0.91)*/
{63, 0,123,__LINE__, 0xbfe91103, 0x985da83f, 0xbfeccccc, 0xccccccca},	/* -0.783327=f(-0.9)*/
{64, 0,123,__LINE__, 0xbfe8ddc5, 0x91c8beae, 0xbfec7ae1, 0x47ae1478},	/* -0.777072=f(-0.89)*/
{63, 0,123,__LINE__, 0xbfe8a9e4, 0x94d40e8e, 0xbfec28f5, 0xc28f5c26},	/* -0.770739=f(-0.88)*/
{62, 0,123,__LINE__, 0xbfe87561, 0xf57d26ce, 0xbfebd70a, 0x3d70a3d4},	/* -0.764329=f(-0.87)*/
{63, 0,123,__LINE__, 0xbfe8403f, 0x0be4dd7c, 0xbfeb851e, 0xb851eb82},	/* -0.757843=f(-0.86)*/
{64, 0,123,__LINE__, 0xbfe80a7d, 0x34468081, 0xbfeb3333, 0x33333330},	/* -0.75128=f(-0.85)*/
{63, 0,123,__LINE__, 0xbfe7d41d, 0xceeeeb79, 0xbfeae147, 0xae147ade},	/* -0.744643=f(-0.84)*/
{62, 0,123,__LINE__, 0xbfe79d22, 0x403382e4, 0xbfea8f5c, 0x28f5c28c},	/* -0.737931=f(-0.83)*/
{63, 0,123,__LINE__, 0xbfe7658b, 0xf06914e6, 0xbfea3d70, 0xa3d70a3a},	/* -0.731146=f(-0.82)*/
{64, 0,123,__LINE__, 0xbfe72d5c, 0x4bda9fd4, 0xbfe9eb85, 0x1eb851e8},	/* -0.724287=f(-0.81)*/
{62, 0,123,__LINE__, 0xbfe6f494, 0xc2bffeca, 0xbfe99999, 0x99999996},	/* -0.717356=f(-0.8)*/
{62, 0,123,__LINE__, 0xbfe6bb36, 0xc9347c8b, 0xbfe947ae, 0x147ae144},	/* -0.710353=f(-0.79)*/
{62, 0,123,__LINE__, 0xbfe68143, 0xd72d4ce2, 0xbfe8f5c2, 0x8f5c28f2},	/* -0.703279=f(-0.78)*/
{64, 0,123,__LINE__, 0xbfe646bd, 0x686fecc4, 0xbfe8a3d7, 0x0a3d70a0},	/* -0.696135=f(-0.77)*/
{62, 0,123,__LINE__, 0xbfe60ba4, 0xfc88697a, 0xbfe851eb, 0x851eb84e},	/* -0.688921=f(-0.76)*/
{62, 0,123,__LINE__, 0xbfe5cffc, 0x16bf8f0a, 0xbfe7ffff, 0xfffffffc},	/* -0.681639=f(-0.75)*/
{63, 0,123,__LINE__, 0xbfe593c4, 0x3e10fe1d, 0xbfe7ae14, 0x7ae147aa},	/* -0.674288=f(-0.74)*/
{64, 0,123,__LINE__, 0xbfe556fe, 0xfd2129ae, 0xbfe75c28, 0xf5c28f58},	/* -0.66687=f(-0.73)*/
{62, 0,123,__LINE__, 0xbfe519ad, 0xe2333cbb, 0xbfe70a3d, 0x70a3d706},	/* -0.659385=f(-0.72)*/
{62, 0,123,__LINE__, 0xbfe4dbd2, 0x7f1ee840, 0xbfe6b851, 0xeb851eb4},	/* -0.651834=f(-0.71)*/
{62, 0,123,__LINE__, 0xbfe49d6e, 0x694619b5, 0xbfe66666, 0x66666662},	/* -0.644218=f(-0.7)*/
{64, 0,123,__LINE__, 0xbfe45e83, 0x398a9a5d, 0xbfe6147a, 0xe147ae10},	/* -0.636537=f(-0.69)*/
{63, 0,123,__LINE__, 0xbfe41f12, 0x8c4397a9, 0xbfe5c28f, 0x5c28f5be},	/* -0.628793=f(-0.68)*/
{62, 0,123,__LINE__, 0xbfe3df1e, 0x013314e8, 0xbfe570a3, 0xd70a3d6c},	/* -0.620986=f(-0.67)*/
{63, 0,123,__LINE__, 0xbfe39ea7, 0x3b7b469c, 0xbfe51eb8, 0x51eb851a},	/* -0.613117=f(-0.66)*/
{64, 0,123,__LINE__, 0xbfe35daf, 0xe193d7a7, 0xbfe4cccc, 0xccccccc8},	/* -0.605186=f(-0.65)*/
{63, 0,123,__LINE__, 0xbfe31c39, 0x9d3f18a4, 0xbfe47ae1, 0x47ae1476},	/* -0.597195=f(-0.64)*/
{62, 0,123,__LINE__, 0xbfe2da46, 0x1b7f19a8, 0xbfe428f5, 0xc28f5c24},	/* -0.589145=f(-0.63)*/
{62, 0,123,__LINE__, 0xbfe297d7, 0x0c8aaec3, 0xbfe3d70a, 0x3d70a3d2},	/* -0.581035=f(-0.62)*/
{64, 0,123,__LINE__, 0xbfe254ee, 0x23c25f70, 0xbfe3851e, 0xb851eb80},	/* -0.572867=f(-0.61)*/
{63, 0,123,__LINE__, 0xbfe2118d, 0x17a54155, 0xbfe33333, 0x3333332e},	/* -0.564642=f(-0.6)*/
{62, 0,123,__LINE__, 0xbfe1cdb5, 0xa1c5be8e, 0xbfe2e147, 0xae147adc},	/* -0.556361=f(-0.59)*/
{62, 0,123,__LINE__, 0xbfe18969, 0x7ebe47d0, 0xbfe28f5c, 0x28f5c28a},	/* -0.548024=f(-0.58)*/
{64, 0,123,__LINE__, 0xbfe144aa, 0x6e25f2ae, 0xbfe23d70, 0xa3d70a38},	/* -0.539632=f(-0.57)*/
{62, 0,123,__LINE__, 0xbfe0ff7a, 0x3285044d, 0xbfe1eb85, 0x1eb851e6},	/* -0.531186=f(-0.56)*/
{61, 0,123,__LINE__, 0xbfe0b9da, 0x914968cf, 0xbfe19999, 0x99999994},	/* -0.522687=f(-0.55)*/
{63, 0,123,__LINE__, 0xbfe073cd, 0x52bb17bc, 0xbfe147ae, 0x147ae142},	/* -0.514136=f(-0.54)*/
{64, 0,123,__LINE__, 0xbfe02d54, 0x41f065c8, 0xbfe0f5c2, 0x8f5c28f0},	/* -0.505533=f(-0.53)*/
{61, 0,123,__LINE__, 0xbfdfcce2, 0x5984884b, 0xbfe0a3d7, 0x0a3d709e},	/* -0.49688=f(-0.52)*/
{61, 0,123,__LINE__, 0xbfdf3e4b, 0xc780db99, 0xbfe051eb, 0x851eb84c},	/* -0.488177=f(-0.51)*/
{62, 0,123,__LINE__, 0xbfdeaee8, 0x744b05e5, 0xbfdfffff, 0xfffffff4},	/* -0.479426=f(-0.5)*/
{64, 0,123,__LINE__, 0xbfde1ebc, 0x0b962615, 0xbfdf5c28, 0xf5c28f50},	/* -0.470626=f(-0.49)*/
{62, 0,123,__LINE__, 0xbfdd8dca, 0x3e3b2b2a, 0xbfdeb851, 0xeb851eac},	/* -0.461779=f(-0.48)*/
{61, 0,123,__LINE__, 0xbfdcfc16, 0xc220a425, 0xbfde147a, 0xe147ae08},	/* -0.452886=f(-0.47)*/
{62, 0,123,__LINE__, 0xbfdc69a5, 0x52226ed4, 0xbfdd70a3, 0xd70a3d64},	/* -0.443948=f(-0.46)*/
{64, 0,123,__LINE__, 0xbfdbd679, 0xadf94619, 0xbfdccccc, 0xccccccc0},	/* -0.434966=f(-0.45)*/
{61, 0,123,__LINE__, 0xbfdb4297, 0x9a223055, 0xbfdc28f5, 0xc28f5c1c},	/* -0.425939=f(-0.44)*/
{61, 0,123,__LINE__, 0xbfdaae02, 0xdfc5ce99, 0xbfdb851e, 0xb851eb78},	/* -0.416871=f(-0.43)*/
{61, 0,123,__LINE__, 0xbfda18bf, 0x4c9f8d38, 0xbfdae147, 0xae147ad4},	/* -0.40776=f(-0.42)*/
{64, 0,123,__LINE__, 0xbfd982d0, 0xb2e4b65f, 0xbfda3d70, 0xa3d70a30},	/* -0.398609=f(-0.41)*/
{61, 0,123,__LINE__, 0xbfd8ec3a, 0xe92b675e, 0xbfd99999, 0x9999998c},	/* -0.389418=f(-0.4)*/
{61, 0,123,__LINE__, 0xbfd85501, 0xca516938, 0xbfd8f5c2, 0x8f5c28e8},	/* -0.380188=f(-0.39)*/
{61, 0,123,__LINE__, 0xbfd7bd29, 0x3562ed2c, 0xbfd851eb, 0x851eb844},	/* -0.37092=f(-0.38)*/
{64, 0,123,__LINE__, 0xbfd724b5, 0x0d812dd2, 0xbfd7ae14, 0x7ae147a0},	/* -0.361615=f(-0.37)*/
{61, 0,123,__LINE__, 0xbfd68ba9, 0x39c8f57c, 0xbfd70a3d, 0x70a3d6fc},	/* -0.352274=f(-0.36)*/
{61, 0,123,__LINE__, 0xbfd5f209, 0xa5390a7e, 0xbfd66666, 0x66666658},	/* -0.342898=f(-0.35)*/
{61, 0,123,__LINE__, 0xbfd557da, 0x3e9881fa, 0xbfd5c28f, 0x5c28f5b4},	/* -0.333487=f(-0.34)*/
{64, 0,123,__LINE__, 0xbfd4bd1e, 0xf85cf9f3, 0xbfd51eb8, 0x51eb8510},	/* -0.324043=f(-0.33)*/
{61, 0,123,__LINE__, 0xbfd421db, 0xc890bb2c, 0xbfd47ae1, 0x47ae146c},	/* -0.314567=f(-0.32)*/
{60, 0,123,__LINE__, 0xbfd38614, 0xa8b8c3a1, 0xbfd3d70a, 0x3d70a3c8},	/* -0.305059=f(-0.31)*/
{61, 0,123,__LINE__, 0xbfd2e9cd, 0x95baba25, 0xbfd33333, 0x33333324},	/* -0.29552=f(-0.3)*/
{64, 0,123,__LINE__, 0xbfd24d0a, 0x8fc2cbe7, 0xbfd28f5c, 0x28f5c280},	/* -0.285952=f(-0.29)*/
{62, 0,123,__LINE__, 0xbfd1afcf, 0x9a29747b, 0xbfd1eb85, 0x1eb851dc},	/* -0.276356=f(-0.28)*/
{61, 0,123,__LINE__, 0xbfd11220, 0xbb593115, 0xbfd147ae, 0x147ae138},	/* -0.266731=f(-0.27)*/
{61, 0,123,__LINE__, 0xbfd07401, 0xfcb41fad, 0xbfd0a3d7, 0x0a3d7094},	/* -0.257081=f(-0.26)*/
{64, 0,123,__LINE__, 0xbfcfaaee, 0xd4f31558, 0xbfcfffff, 0xffffffe0},	/* -0.247404=f(-0.25)*/
{60, 0,123,__LINE__, 0xbfce6d0a, 0x2756c39d, 0xbfceb851, 0xeb851e98},	/* -0.237703=f(-0.24)*/
{59, 0,123,__LINE__, 0xbfcd2e5e, 0x13e741f8, 0xbfcd70a3, 0xd70a3d50},	/* -0.227978=f(-0.23)*/
{60, 0,123,__LINE__, 0xbfcbeef2, 0xc3134b57, 0xbfcc28f5, 0xc28f5c08},	/* -0.21823=f(-0.22)*/
{64, 0,123,__LINE__, 0xbfcaaed0, 0x622ee727, 0xbfcae147, 0xae147ac0},	/* -0.20846=f(-0.21)*/
{60, 0,123,__LINE__, 0xbfc96dff, 0x233dd29b, 0xbfc99999, 0x99999978},	/* -0.198669=f(-0.2)*/
{59, 0,123,__LINE__, 0xbfc82c87, 0x3cbdcb3c, 0xbfc851eb, 0x851eb830},	/* -0.188859=f(-0.19)*/
{60, 0,123,__LINE__, 0xbfc6ea70, 0xe970bc23, 0xbfc70a3d, 0x70a3d6e8},	/* -0.17903=f(-0.18)*/
{64, 0,123,__LINE__, 0xbfc5a7c4, 0x6826cf41, 0xbfc5c28f, 0x5c28f5a0},	/* -0.169182=f(-0.17)*/
{60, 0,123,__LINE__, 0xbfc46489, 0xfb88640c, 0xbfc47ae1, 0x47ae1458},	/* -0.159318=f(-0.16)*/
{60, 0,123,__LINE__, 0xbfc320c9, 0xe9dfecff, 0xbfc33333, 0x33333310},	/* -0.149438=f(-0.15)*/
{60, 0,123,__LINE__, 0xbfc1dc8c, 0x7ce3b54b, 0xbfc1eb85, 0x1eb851c8},	/* -0.139543=f(-0.14)*/
{64, 0,123,__LINE__, 0xbfc097da, 0x017f9018, 0xbfc0a3d7, 0x0a3d7080},	/* -0.129634=f(-0.13)*/
{60, 0,123,__LINE__, 0xbfbea575, 0x8f3ce586, 0xbfbeb851, 0xeb851e71},	/* -0.119712=f(-0.12)*/
{59, 0,123,__LINE__, 0xbfbc1a6e, 0x43e7f6e4, 0xbfbc28f5, 0xc28f5be2},	/* -0.109778=f(-0.11)*/
{59, 0,123,__LINE__, 0xbfb98eae, 0xcb8bcae6, 0xbfb99999, 0x99999953},	/* -0.0998334=f(-0.1)*/
{61, 0,123,__LINE__, 0xbfb70247, 0xd56ad970, 0xbfb70a3d, 0x70a3d6c4},	/* -0.0898785=f(-0.09)*/
{60, 0,123,__LINE__, 0xbfb4754a, 0x151143d0, 0xbfb47ae1, 0x47ae1435},	/* -0.0799147=f(-0.08)*/
{59, 0,123,__LINE__, 0xbfb1e7c6, 0x41e760bb, 0xbfb1eb85, 0x1eb851a6},	/* -0.0699428=f(-0.07)*/
{58, 0,123,__LINE__, 0xbfaeb39a, 0x2d885e0b, 0xbfaeb851, 0xeb851e2d},	/* -0.059964=f(-0.06)*/
{60, 0,123,__LINE__, 0xbfa996de, 0xa2ff63b0, 0xbfa99999, 0x9999990e},	/* -0.0499792=f(-0.05)*/
{59, 0,123,__LINE__, 0xbfa4797b, 0x650a726f, 0xbfa47ae1, 0x47ae13ef},	/* -0.0399893=f(-0.04)*/
{57, 0,123,__LINE__, 0xbf9eb723, 0xf19666ae, 0xbf9eb851, 0xeb851da0},	/* -0.0299955=f(-0.03)*/
{57, 0,123,__LINE__, 0xbf947a87, 0xcda5574e, 0xbf947ae1, 0x47ae1362},	/* -0.0199987=f(-0.02)*/
{57, 0,123,__LINE__, 0xbf847aca, 0xe915e5d5, 0xbf847ae1, 0x47ae1249},	/* -0.00999983=f(-0.01)*/
{64, 0,123,__LINE__, 0x3cd19000, 0x00000000, 0x3cd19000, 0x00000000},	/* 9.74915e-16=f(9.74915e-16)*/
{64, 0,123,__LINE__, 0x3f847aca, 0xe915ea39, 0x3f847ae1, 0x47ae16ad},	/* 0.00999983=f(0.01)*/
{64, 0,123,__LINE__, 0x3f947a87, 0xcda55980, 0x3f947ae1, 0x47ae1594},	/* 0.0199987=f(0.02)*/
{64, 0,123,__LINE__, 0x3f9eb723, 0xf19668e0, 0x3f9eb851, 0xeb851fd2},	/* 0.0299955=f(0.03)*/
{64, 0,123,__LINE__, 0x3fa4797b, 0x650a7388, 0x3fa47ae1, 0x47ae1508},	/* 0.0399893=f(0.04)*/
{64, 0,123,__LINE__, 0x3fa996de, 0xa2ff64c9, 0x3fa99999, 0x99999a27},	/* 0.0499792=f(0.05)*/
{64, 0,123,__LINE__, 0x3faeb39a, 0x2d885f24, 0x3faeb851, 0xeb851f46},	/* 0.059964=f(0.06)*/
{64, 0,123,__LINE__, 0x3fb1e7c6, 0x41e76147, 0x3fb1eb85, 0x1eb85232},	/* 0.0699428=f(0.07)*/
{64, 0,123,__LINE__, 0x3fb4754a, 0x1511445b, 0x3fb47ae1, 0x47ae14c1},	/* 0.0799147=f(0.08)*/
{64, 0,123,__LINE__, 0x3fb70247, 0xd56ad9fb, 0x3fb70a3d, 0x70a3d750},	/* 0.0898785=f(0.09)*/
{64, 0,123,__LINE__, 0x3fb98eae, 0xcb8bcb71, 0x3fb99999, 0x999999df},	/* 0.0998334=f(0.1)*/
{64, 0,123,__LINE__, 0x3fbc1a6e, 0x43e7f76f, 0x3fbc28f5, 0xc28f5c6e},	/* 0.109778=f(0.11)*/
{64, 0,123,__LINE__, 0x3fbea575, 0x8f3ce611, 0x3fbeb851, 0xeb851efd},	/* 0.119712=f(0.12)*/
{64, 0,123,__LINE__, 0x3fc097da, 0x017f905e, 0x3fc0a3d7, 0x0a3d70c6},	/* 0.129634=f(0.13)*/
{64, 0,123,__LINE__, 0x3fc1dc8c, 0x7ce3b591, 0x3fc1eb85, 0x1eb8520e},	/* 0.139543=f(0.14)*/
{64, 0,123,__LINE__, 0x3fc320c9, 0xe9dfed45, 0x3fc33333, 0x33333356},	/* 0.149438=f(0.15)*/
{64, 0,123,__LINE__, 0x3fc46489, 0xfb886451, 0x3fc47ae1, 0x47ae149e},	/* 0.159318=f(0.16)*/
{64, 0,123,__LINE__, 0x3fc5a7c4, 0x6826cf86, 0x3fc5c28f, 0x5c28f5e6},	/* 0.169182=f(0.17)*/
{64, 0,123,__LINE__, 0x3fc6ea70, 0xe970bc68, 0x3fc70a3d, 0x70a3d72e},	/* 0.17903=f(0.18)*/
{64, 0,123,__LINE__, 0x3fc82c87, 0x3cbdcb81, 0x3fc851eb, 0x851eb876},	/* 0.188859=f(0.19)*/
{64, 0,123,__LINE__, 0x3fc96dff, 0x233dd2e0, 0x3fc99999, 0x999999be},	/* 0.198669=f(0.2)*/
{64, 0,123,__LINE__, 0x3fcaaed0, 0x622ee76b, 0x3fcae147, 0xae147b06},	/* 0.20846=f(0.21)*/
{64, 0,123,__LINE__, 0x3fcbeef2, 0xc3134b9b, 0x3fcc28f5, 0xc28f5c4e},	/* 0.21823=f(0.22)*/
{64, 0,123,__LINE__, 0x3fcd2e5e, 0x13e7423c, 0x3fcd70a3, 0xd70a3d96},	/* 0.227978=f(0.23)*/
{64, 0,123,__LINE__, 0x3fce6d0a, 0x2756c3e1, 0x3fceb851, 0xeb851ede},	/* 0.237703=f(0.24)*/
{64, 0,123,__LINE__, 0x3fcfaaee, 0xd4f3159c, 0x3fd00000, 0x00000013},	/* 0.247404=f(0.25)*/
{64, 0,123,__LINE__, 0x3fd07401, 0xfcb41fcf, 0x3fd0a3d7, 0x0a3d70b7},	/* 0.257081=f(0.26)*/
{64, 0,123,__LINE__, 0x3fd11220, 0xbb593136, 0x3fd147ae, 0x147ae15b},	/* 0.266731=f(0.27)*/
{64, 0,123,__LINE__, 0x3fd1afcf, 0x9a29749c, 0x3fd1eb85, 0x1eb851ff},	/* 0.276356=f(0.28)*/
{64, 0,123,__LINE__, 0x3fd24d0a, 0x8fc2cc09, 0x3fd28f5c, 0x28f5c2a3},	/* 0.285952=f(0.29)*/
{64, 0,123,__LINE__, 0x3fd2e9cd, 0x95baba46, 0x3fd33333, 0x33333347},	/* 0.29552=f(0.3)*/
{64, 0,123,__LINE__, 0x3fd38614, 0xa8b8c3c2, 0x3fd3d70a, 0x3d70a3eb},	/* 0.305059=f(0.31)*/
{64, 0,123,__LINE__, 0x3fd421db, 0xc890bb4d, 0x3fd47ae1, 0x47ae148f},	/* 0.314567=f(0.32)*/
{64, 0,123,__LINE__, 0x3fd4bd1e, 0xf85cfa14, 0x3fd51eb8, 0x51eb8533},	/* 0.324043=f(0.33)*/
{64, 0,123,__LINE__, 0x3fd557da, 0x3e98821b, 0x3fd5c28f, 0x5c28f5d7},	/* 0.333487=f(0.34)*/
{64, 0,123,__LINE__, 0x3fd5f209, 0xa5390a9e, 0x3fd66666, 0x6666667b},	/* 0.342898=f(0.35)*/
{64, 0,123,__LINE__, 0x3fd68ba9, 0x39c8f59d, 0x3fd70a3d, 0x70a3d71f},	/* 0.352274=f(0.36)*/
{64, 0,123,__LINE__, 0x3fd724b5, 0x0d812df2, 0x3fd7ae14, 0x7ae147c3},	/* 0.361615=f(0.37)*/
{64, 0,123,__LINE__, 0x3fd7bd29, 0x3562ed4c, 0x3fd851eb, 0x851eb867},	/* 0.37092=f(0.38)*/
{64, 0,123,__LINE__, 0x3fd85501, 0xca516959, 0x3fd8f5c2, 0x8f5c290b},	/* 0.380188=f(0.39)*/
{64, 0,123,__LINE__, 0x3fd8ec3a, 0xe92b677e, 0x3fd99999, 0x999999af},	/* 0.389418=f(0.4)*/
{64, 0,123,__LINE__, 0x3fd982d0, 0xb2e4b67f, 0x3fda3d70, 0xa3d70a53},	/* 0.398609=f(0.41)*/
{63, 0,123,__LINE__, 0x3fda18bf, 0x4c9f8d57, 0x3fdae147, 0xae147af7},	/* 0.40776=f(0.42)*/
{64, 0,123,__LINE__, 0x3fdaae02, 0xdfc5ceb9, 0x3fdb851e, 0xb851eb9b},	/* 0.416871=f(0.43)*/
{64, 0,123,__LINE__, 0x3fdb4297, 0x9a223075, 0x3fdc28f5, 0xc28f5c3f},	/* 0.425939=f(0.44)*/
{64, 0,123,__LINE__, 0x3fdbd679, 0xadf94639, 0x3fdccccc, 0xcccccce3},	/* 0.434966=f(0.45)*/
{64, 0,123,__LINE__, 0x3fdc69a5, 0x52226ef4, 0x3fdd70a3, 0xd70a3d87},	/* 0.443948=f(0.46)*/
{64, 0,123,__LINE__, 0x3fdcfc16, 0xc220a444, 0x3fde147a, 0xe147ae2b},	/* 0.452886=f(0.47)*/
{64, 0,123,__LINE__, 0x3fdd8dca, 0x3e3b2b49, 0x3fdeb851, 0xeb851ecf},	/* 0.461779=f(0.48)*/
{64, 0,123,__LINE__, 0x3fde1ebc, 0x0b962634, 0x3fdf5c28, 0xf5c28f73},	/* 0.470626=f(0.49)*/
{64, 0,123,__LINE__, 0x3fdeaee8, 0x744b0603, 0x3fe00000, 0x0000000b},	/* 0.479426=f(0.5)*/
{64, 0,123,__LINE__, 0x3fdf3e4b, 0xc780dbb7, 0x3fe051eb, 0x851eb85d},	/* 0.488177=f(0.51)*/
{64, 0,123,__LINE__, 0x3fdfcce2, 0x59848869, 0x3fe0a3d7, 0x0a3d70af},	/* 0.49688=f(0.52)*/
{64, 0,123,__LINE__, 0x3fe02d54, 0x41f065d7, 0x3fe0f5c2, 0x8f5c2901},	/* 0.505533=f(0.53)*/
{64, 0,123,__LINE__, 0x3fe073cd, 0x52bb17cb, 0x3fe147ae, 0x147ae153},	/* 0.514136=f(0.54)*/
{64, 0,123,__LINE__, 0x3fe0b9da, 0x914968dd, 0x3fe19999, 0x999999a5},	/* 0.522687=f(0.55)*/
{64, 0,123,__LINE__, 0x3fe0ff7a, 0x3285045c, 0x3fe1eb85, 0x1eb851f7},	/* 0.531186=f(0.56)*/
{64, 0,123,__LINE__, 0x3fe144aa, 0x6e25f2bc, 0x3fe23d70, 0xa3d70a49},	/* 0.539632=f(0.57)*/
{64, 0,123,__LINE__, 0x3fe18969, 0x7ebe47de, 0x3fe28f5c, 0x28f5c29b},	/* 0.548024=f(0.58)*/
{64, 0,123,__LINE__, 0x3fe1cdb5, 0xa1c5be9c, 0x3fe2e147, 0xae147aed},	/* 0.556361=f(0.59)*/
{64, 0,123,__LINE__, 0x3fe2118d, 0x17a54163, 0x3fe33333, 0x3333333f},	/* 0.564642=f(0.6)*/
{64, 0,123,__LINE__, 0x3fe254ee, 0x23c25f7e, 0x3fe3851e, 0xb851eb91},	/* 0.572867=f(0.61)*/
{64, 0,123,__LINE__, 0x3fe297d7, 0x0c8aaed1, 0x3fe3d70a, 0x3d70a3e3},	/* 0.581035=f(0.62)*/
{64, 0,123,__LINE__, 0x3fe2da46, 0x1b7f19b6, 0x3fe428f5, 0xc28f5c35},	/* 0.589145=f(0.63)*/
{64, 0,123,__LINE__, 0x3fe31c39, 0x9d3f18b1, 0x3fe47ae1, 0x47ae1487},	/* 0.597195=f(0.64)*/
{64, 0,123,__LINE__, 0x3fe35daf, 0xe193d7b5, 0x3fe4cccc, 0xccccccd9},	/* 0.605186=f(0.65)*/
{64, 0,123,__LINE__, 0x3fe39ea7, 0x3b7b46aa, 0x3fe51eb8, 0x51eb852b},	/* 0.613117=f(0.66)*/
{64, 0,123,__LINE__, 0x3fe3df1e, 0x013314f5, 0x3fe570a3, 0xd70a3d7d},	/* 0.620986=f(0.67)*/
{64, 0,123,__LINE__, 0x3fe41f12, 0x8c4397b6, 0x3fe5c28f, 0x5c28f5cf},	/* 0.628793=f(0.68)*/
{64, 0,123,__LINE__, 0x3fe45e83, 0x398a9a6a, 0x3fe6147a, 0xe147ae21},	/* 0.636537=f(0.69)*/
{64, 0,123,__LINE__, 0x3fe49d6e, 0x694619c2, 0x3fe66666, 0x66666673},	/* 0.644218=f(0.7)*/
{64, 0,123,__LINE__, 0x3fe4dbd2, 0x7f1ee84d, 0x3fe6b851, 0xeb851ec5},	/* 0.651834=f(0.71)*/
{64, 0,123,__LINE__, 0x3fe519ad, 0xe2333cc8, 0x3fe70a3d, 0x70a3d717},	/* 0.659385=f(0.72)*/
{64, 0,123,__LINE__, 0x3fe556fe, 0xfd2129ba, 0x3fe75c28, 0xf5c28f69},	/* 0.66687=f(0.73)*/
{64, 0,123,__LINE__, 0x3fe593c4, 0x3e10fe2a, 0x3fe7ae14, 0x7ae147bb},	/* 0.674288=f(0.74)*/
{64, 0,123,__LINE__, 0x3fe5cffc, 0x16bf8f17, 0x3fe80000, 0x0000000d},	/* 0.681639=f(0.75)*/
{64, 0,123,__LINE__, 0x3fe60ba4, 0xfc886987, 0x3fe851eb, 0x851eb85f},	/* 0.688921=f(0.76)*/
{64, 0,123,__LINE__, 0x3fe646bd, 0x686fecd0, 0x3fe8a3d7, 0x0a3d70b1},	/* 0.696135=f(0.77)*/
{64, 0,123,__LINE__, 0x3fe68143, 0xd72d4cee, 0x3fe8f5c2, 0x8f5c2903},	/* 0.703279=f(0.78)*/
{64, 0,123,__LINE__, 0x3fe6bb36, 0xc9347c97, 0x3fe947ae, 0x147ae155},	/* 0.710353=f(0.79)*/
{64, 0,123,__LINE__, 0x3fe6f494, 0xc2bffed6, 0x3fe99999, 0x999999a7},	/* 0.717356=f(0.8)*/
{64, 0,123,__LINE__, 0x3fe72d5c, 0x4bda9fe0, 0x3fe9eb85, 0x1eb851f9},	/* 0.724287=f(0.81)*/
{64, 0,123,__LINE__, 0x3fe7658b, 0xf06914f2, 0x3fea3d70, 0xa3d70a4b},	/* 0.731146=f(0.82)*/
{64, 0,123,__LINE__, 0x3fe79d22, 0x403382f0, 0x3fea8f5c, 0x28f5c29d},	/* 0.737931=f(0.83)*/
{64, 0,123,__LINE__, 0x3fe7d41d, 0xceeeeb84, 0x3feae147, 0xae147aef},	/* 0.744643=f(0.84)*/
{64, 0,123,__LINE__, 0x3fe80a7d, 0x3446808c, 0x3feb3333, 0x33333341},	/* 0.75128=f(0.85)*/
{64, 0,123,__LINE__, 0x3fe8403f, 0x0be4dd87, 0x3feb851e, 0xb851eb93},	/* 0.757843=f(0.86)*/
{64, 0,123,__LINE__, 0x3fe87561, 0xf57d26d9, 0x3febd70a, 0x3d70a3e5},	/* 0.764329=f(0.87)*/
{64, 0,123,__LINE__, 0x3fe8a9e4, 0x94d40e99, 0x3fec28f5, 0xc28f5c37},	/* 0.770739=f(0.88)*/
{64, 0,123,__LINE__, 0x3fe8ddc5, 0x91c8beb9, 0x3fec7ae1, 0x47ae1489},	/* 0.777072=f(0.89)*/
{64, 0,123,__LINE__, 0x3fe91103, 0x985da84a, 0x3feccccc, 0xccccccdb},	/* 0.783327=f(0.9)*/
{64, 0,123,__LINE__, 0x3fe9439d, 0x58c1379c, 0x3fed1eb8, 0x51eb852d},	/* 0.789504=f(0.91)*/
{64, 0,123,__LINE__, 0x3fe97591, 0x87566d13, 0x3fed70a3, 0xd70a3d7f},	/* 0.795602=f(0.92)*/
{64, 0,123,__LINE__, 0x3fe9a6de, 0xdcbd5a5c, 0x3fedc28f, 0x5c28f5d1},	/* 0.80162=f(0.93)*/
{64, 0,123,__LINE__, 0x3fe9d784, 0x15db83ed, 0x3fee147a, 0xe147ae23},	/* 0.807558=f(0.94)*/
{63, 0,123,__LINE__, 0x3fea077f, 0xf3e42678, 0x3fee6666, 0x66666675},	/* 0.813416=f(0.95)*/
{64, 0,123,__LINE__, 0x3fea36d1, 0x3c606030, 0x3feeb851, 0xeb851ec7},	/* 0.819192=f(0.96)*/
{63, 0,123,__LINE__, 0x3fea6576, 0xb9373dab, 0x3fef0a3d, 0x70a3d719},	/* 0.824886=f(0.97)*/
{64, 0,123,__LINE__, 0x3fea936f, 0x38b5aa16, 0x3fef5c28, 0xf5c28f6b},	/* 0.830497=f(0.98)*/
{64, 0,123,__LINE__, 0x3feac0b9, 0x8d9642a5, 0x3fefae14, 0x7ae147bd},	/* 0.836026=f(0.99)*/
{64, 0,123,__LINE__, 0x3feaed54, 0x8f090cf6, 0x3ff00000, 0x00000007},	/* 0.841471=f(1)*/
{63, 0,123,__LINE__, 0x3feb193f, 0x18bb103d, 0x3ff028f5, 0xc28f5c30},	/* 0.846832=f(1.01)*/
{64, 0,123,__LINE__, 0x3feb4478, 0x0addd10a, 0x3ff051eb, 0x851eb859},	/* 0.852108=f(1.02)*/
{63, 0,123,__LINE__, 0x3feb6efe, 0x4a2eaf69, 0x3ff07ae1, 0x47ae1482},	/* 0.857299=f(1.03)*/
{64, 0,123,__LINE__, 0x3feb98d0, 0xbffe2746, 0x3ff0a3d7, 0x0a3d70ab},	/* 0.862404=f(1.04)*/
{63, 0,123,__LINE__, 0x3febc1ee, 0x5a36f2c8, 0x3ff0cccc, 0xccccccd4},	/* 0.867423=f(1.05)*/
{64, 0,123,__LINE__, 0x3febea56, 0x0b650e8a, 0x3ff0f5c2, 0x8f5c28fd},	/* 0.872355=f(1.06)*/
{64, 0,123,__LINE__, 0x3fec1206, 0xcabc9f7e, 0x3ff11eb8, 0x51eb8526},	/* 0.877201=f(1.07)*/
{64, 0,123,__LINE__, 0x3fec38ff, 0x9420ba42, 0x3ff147ae, 0x147ae14f},	/* 0.881958=f(1.08)*/
{63, 0,123,__LINE__, 0x3fec5f3f, 0x682a0bcd, 0x3ff170a3, 0xd70a3d78},	/* 0.886627=f(1.09)*/
{64, 0,123,__LINE__, 0x3fec84c5, 0x4c2d633e, 0x3ff19999, 0x999999a1},	/* 0.891207=f(1.1)*/
{64, 0,123,__LINE__, 0x3feca990, 0x4a421c9a, 0x3ff1c28f, 0x5c28f5ca},	/* 0.895699=f(1.11)*/
{64, 0,123,__LINE__, 0x3feccd9f, 0x71486c64, 0x3ff1eb85, 0x1eb851f3},	/* 0.9001=f(1.12)*/
{64, 0,123,__LINE__, 0x3fecf0f1, 0xd4ef8bd4, 0x3ff2147a, 0xe147ae1c},	/* 0.904412=f(1.13)*/
{64, 0,123,__LINE__, 0x3fed1386, 0x8dbbc58c, 0x3ff23d70, 0xa3d70a45},	/* 0.908633=f(1.14)*/
{64, 0,123,__LINE__, 0x3fed355c, 0xb90c629f, 0x3ff26666, 0x6666666e},	/* 0.912764=f(1.15)*/
{64, 0,123,__LINE__, 0x3fed5673, 0x792177ca, 0x3ff28f5c, 0x28f5c297},	/* 0.916803=f(1.16)*/
{64, 0,123,__LINE__, 0x3fed76c9, 0xf52192b2, 0x3ff2b851, 0xeb851ec0},	/* 0.920751=f(1.17)*/
{64, 0,123,__LINE__, 0x3fed965f, 0x591f4707, 0x3ff2e147, 0xae147ae9},	/* 0.924606=f(1.18)*/
{64, 0,123,__LINE__, 0x3fedb532, 0xd61e9b64, 0x3ff30a3d, 0x70a3d712},	/* 0.928369=f(1.19)*/
{ 1, 0,123,__LINE__, 0x3cb1a626, 0x33145c07, 0xc01921fb, 0x54442d18},	/* 2.44929e-16=f(-6.28319)*/
{63, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0xc012d97c, 0x7f3321d2},	/* 1=f(-4.71239)*/
{64, 0,123,__LINE__, 0xbca1a626, 0x33145c07, 0xc00921fb, 0x54442d18},	/* -1.22465e-16=f(-3.14159)*/
{63, 0,123,__LINE__, 0xbff00000, 0x00000000, 0xbff921fb, 0x54442d18},	/* -1=f(-1.5708)*/
{64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},	/* 0=f(0)*/
{63, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x3ff921fb, 0x54442d18},	/* 1=f(1.5708)*/
{ 1, 0,123,__LINE__, 0x3ca1a626, 0x33145c07, 0x400921fb, 0x54442d18},	/* 1.22465e-16=f(3.14159)*/
{63, 0,123,__LINE__, 0xbff00000, 0x00000000, 0x4012d97c, 0x7f3321d2},	/* -1=f(4.71239)*/
{62, 0,123,__LINE__, 0x3fef9df4, 0x7f1c903d, 0xc03e0000, 0x00000000},	/* 0.988032=f(-30)*/
{55, 0,123,__LINE__, 0x3f9a477a, 0xe66f2641, 0xc03c4ccc, 0xcccccccd},	/* 0.0256633=f(-28.3)*/
{64, 0,123,__LINE__, 0xbfefd421, 0x46de2a06, 0xc03a9999, 0x9999999a},	/* -0.994645=f(-26.6)*/
{58, 0,123,__LINE__, 0x3fcd85cc, 0x69f5e2c5, 0xc038e666, 0x66666667},	/* 0.230646=f(-24.9)*/
{62, 0,123,__LINE__, 0x3feded3d, 0x5814f9b9, 0xc0373333, 0x33333334},	/* 0.93521=f(-23.2)*/
{60, 0,123,__LINE__, 0xbfde2f55, 0x5b73afbf, 0xc0358000, 0x00000001},	/* -0.471639=f(-21.5)*/
{62, 0,123,__LINE__, 0xbfea099d, 0x8186a0b0, 0xc033cccc, 0xccccccce},	/* -0.813674=f(-19.8)*/
{61, 0,123,__LINE__, 0x3fe5cd52, 0x86ac03df, 0xc0321999, 0x9999999b},	/* 0.681314=f(-18.1)*/
{61, 0,123,__LINE__, 0x3fe46b5e, 0xb4816481, 0xc0306666, 0x66666668},	/* 0.638107=f(-16.4)*/
{62, 0,123,__LINE__, 0xbfeb105b, 0xa88e8b6f, 0xc02d6666, 0x6666666a},	/* -0.845747=f(-14.7)*/
{60, 0,123,__LINE__, 0xbfdae404, 0x4881c57a, 0xc02a0000, 0x00000004},	/* -0.420167=f(-13)*/
{63, 0,123,__LINE__, 0x3fee8753, 0x60c2af6d, 0xc0269999, 0x9999999e},	/* 0.954019=f(-11.3)*/
{60, 0,123,__LINE__, 0x3fc65057, 0x0815b824, 0xc0233333, 0x33333338},	/* 0.174327=f(-9.6)*/
{64, 0,123,__LINE__, 0xbfeff753, 0xd53a5fa6, 0xc01f9999, 0x999999a3},	/* -0.998941=f(-7.9)*/
{59, 0,123,__LINE__, 0x3fb54558, 0xdbbecadf, 0xc018cccc, 0xccccccd6},	/* 0.0830894=f(-6.2)*/
{63, 0,123,__LINE__, 0x3fef47ed, 0x3dc74090, 0xc0120000, 0x00000009},	/* 0.97753=f(-4.5)*/
{62, 0,123,__LINE__, 0xbfd57072, 0x235de540, 0xc0066666, 0x66666678},	/* -0.334988=f(-2.8)*/
{63, 0,123,__LINE__, 0xbfec84c5, 0x4c2d6357, 0xbff19999, 0x999999bd},	/* -0.891207=f(-1.1)*/
{64, 0,123,__LINE__, 0x3fe2118d, 0x17a5411e, 0x3fe33333, 0x333332ec},	/* 0.564642=f(0.6)*/
{64, 0,123,__LINE__, 0x3fe7dcd1, 0x2d582f54, 0x40026666, 0x66666654},	/* 0.745705=f(2.3)*/
{63, 0,123,__LINE__, 0xbfe837b9, 0xdddc1e7f, 0x400fffff, 0xffffffee},	/* -0.756802=f(4)*/
{63, 0,123,__LINE__, 0xbfe19f37, 0x497ac7dc, 0x4016cccc, 0xccccccc4},	/* -0.550686=f(5.7)*/
{63, 0,123,__LINE__, 0x3fecc237, 0x7b0529d6, 0x401d9999, 0x99999991},	/* 0.898708=f(7.4)*/
{61, 0,123,__LINE__, 0x3fd46c1b, 0x899fd990, 0x40223333, 0x3333332f},	/* 0.319098=f(9.1)*/
{63, 0,123,__LINE__, 0xbfef63d4, 0x60731b7d, 0x40259999, 0x99999995},	/* -0.980936=f(10.8)*/
{58, 0,123,__LINE__, 0xbfb0fa78, 0xcc21d23a, 0x4028ffff, 0xfffffffb},	/* -0.0663219=f(12.5)*/
{64, 0,123,__LINE__, 0x3fefefd5, 0x973e8001, 0x402c6666, 0x66666661},	/* 0.998027=f(14.2)*/
{59, 0,123,__LINE__, 0xbfc86e0d, 0xd294deed, 0x402fcccc, 0xccccccc7},	/* -0.190859=f(15.9)*/
{62, 0,123,__LINE__, 0xbfee5cef, 0x22f1885f, 0x40319999, 0x99999997},	/* -0.948844=f(17.6)*/
{60, 0,123,__LINE__, 0x3fdbdd06, 0xac2737f1, 0x40334ccc, 0xccccccca},	/* 0.435365=f(19.3)*/
{61, 0,123,__LINE__, 0x3feac5e2, 0x0bb0d821, 0x4034ffff, 0xfffffffd},	/* 0.836656=f(21)*/
{61, 0,123,__LINE__, 0xbfe4d4ae, 0xe6b87cf0, 0x4036b333, 0x33333330},	/* -0.650962=f(22.7)*/
{61, 0,123,__LINE__, 0xbfe567b5, 0x914fe676, 0x40386666, 0x66666663},	/* -0.66891=f(24.4)*/
{61, 0,123,__LINE__, 0x3fea58be, 0x72fc66f8, 0x403a1999, 0x99999996},	/* 0.823333=f(26.1)*/
{59, 0,123,__LINE__, 0x3fdd3b53, 0x753c1a0b, 0x403bcccc, 0xccccccc9},	/* 0.456746=f(27.8)*/
{61, 0,123,__LINE__, 0xbfee1ced, 0xe66aefea, 0x403d7fff, 0xfffffffc},	/* -0.941031=f(29.5)*/
{0},};
void test_sin(m)   {run_vector_1(m,sin_vec,(char *)(sin),"sin","dd");   }	
